@@ -10,7 +10,6 @@
 pub mod client;
 mod errors;
 pub mod location;
-mod msg;
 mod msg_id;
 #[cfg(not(feature = "client-only"))]
 pub mod node;
@@ -20,7 +19,6 @@ mod serialisation;
 pub use self::{
     errors::{Error, Result},
     location::{Aggregation, DstLocation, EndUser, Itinerary, SrcLocation},
-    msg::Msg,
     msg_id::MessageId,
     serialisation::WireMsg,
 };
